/* This file is part of the KDE project
   Copyright 2007,2008 Will Stephenson <wstephenson@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef AKONADI_FACEBOOK_RESOURCE_H
#define AKONADI_FACEBOOK_RESOURCE_H

#include <akonadi/resourcebase.h>
#include <kfacebook/session.h>

#include "ui_facebookconfig.h"

class FacebookResource : public Akonadi::ResourceBase

{
Q_OBJECT
public:
  FacebookResource( const QString & id );
  ~FacebookResource();

protected slots:
  /**
   * Inherited from ResourceBase
   */
  void configure( WId windowId );
  /**
   * Inherited from ResourceBase
   */
  void retrieveCollections();
  /**
   * Gets new items and syncs them into collection
   * Inherited from ResourceBase
   */
  void retrieveItems( const Akonadi::Collection & );
  bool retrieveItem( const Akonadi::Item &, const QSet<QByteArray> & );
  /**
   * Let the session know it can proceed
   */
  void browserLoggedIn();
  /**
   * Process the incoming friends and respond to synchronizeCollection()
   */
  void gotFriends( KJob * );
  /**
   * Process incoming userinfo and respond to requestItemDelivery()
   */
  void gotUserInfo( KJob * );
protected:
  void setupCollection();
private:
  KFacebook::Session * m_session;
  KDialog * m_dialog;
  Ui_ConfigUi m_ui;
  Akonadi::Collection m_collection;
};

#endif

