/* This file is part of the KDE project
   Copyright 2007,2008 Will Stephenson <wstephenson@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "affiliation.h"

class AffiliationPrivate
{
public:
    AffiliationPrivate() : valid( false ), nid( 0 )
    {
    }
    AffiliationPrivate( KFacebook::Affiliation::Type theType, uint theYear, const QString & theName, uint theNid, const QString & theGradStatus ) : valid ( true ), type( theType ), name( theName ), nid( theNid ), gradStatus( theGradStatus )
    {
        year.addYears( theYear );
    }

    bool valid;
    KFacebook::Affiliation::Type type;
    QDate year;
    QString name;
    uint nid;
    QString gradStatus;
};

KFacebook::Affiliation::Affiliation() : d( new AffiliationPrivate )
{
}
KFacebook::Affiliation::Affiliation( KFacebook::Affiliation::Type type, uint year, const QString & name, uint nid, const QString & gradStatus ) : d( new AffiliationPrivate( type, year, name, nid, gradStatus ) )
{
}

KFacebook::Affiliation::Affiliation( const Affiliation & rhs ) : d( new AffiliationPrivate )
{
    operator=( rhs );
}

KFacebook::Affiliation::~Affiliation()
{
    delete d;
}

KFacebook::Affiliation& KFacebook::Affiliation::operator=( const Affiliation & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::Affiliation::isNull() const
{
    return !d->valid;
}

KFacebook::Affiliation::Type KFacebook::Affiliation::type() const
{
    return d->type;
}

QDate KFacebook::Affiliation::year() const
{
    return d->year;
}

QString KFacebook::Affiliation::name() const
{
    return d->name;
}

uint KFacebook::Affiliation::nid() const
{
    return d->nid;
}

QString KFacebook::Affiliation::gradStatus() const
{
    return d->gradStatus;
}

QString KFacebook::Affiliation::toString() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null)";
    } else {
        switch ( type () ) {
            case KFacebook::Affiliation::College:
                asString = QString("College: %1 %2 (%3) (%4)").arg(name()).arg(d->year.year()).arg(gradStatus()).arg(nid());
                break;
            case KFacebook::Affiliation::HighSchool:
                asString = QString("High school: %1 %2 (%3) (%4)").arg(name()).arg(year().year()).arg(gradStatus()).arg(nid());
                break;
            case KFacebook::Affiliation::Work:
                asString = QString("Workplace: %1 %2 (%3)").arg(name()).arg(year().year()).arg(nid());
                break;
            case KFacebook::Affiliation::Region:
                asString = QString("Region: %1 (%3)").arg(name()).arg(nid());
                break;
        }
    }
    return asString;
}

