/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include "education.h"

class EducationPrivate
{
public:
    EducationPrivate() : valid( false )
    {}
    EducationPrivate( const QDate & theYear, const QString & theName, const QStringList & theConcentrations ) : valid( true ), year( theYear ), name( theName ), concentrations( theConcentrations )
    {}
    bool valid;
    QDate year;
    QString name;
    QStringList concentrations;
};

KFacebook::Education::Education() : d( new EducationPrivate )
{
}

KFacebook::Education::Education( const QDate & year, const QString & name, const QStringList & concentrations ) : d( new EducationPrivate( year, name, concentrations ) )
{
}

KFacebook::Education::Education( const Education & rhs ) : d( new EducationPrivate )
{
    operator=( rhs );
}

KFacebook::Education::~Education()
{
    delete d;
}

KFacebook::Education& KFacebook::Education::operator=( const Education & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::Education::isNull() const
{
    return !d->valid;
}

QDate KFacebook::Education::year() const
{
    return d->year;
}

QString KFacebook::Education::name() const
{
    return d->name;
}

QStringList KFacebook::Education::concentrations() const
{
    return d->concentrations;
}

QString KFacebook::Education::toString() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null";
    } else {
        asString = QString("%1 %2 (%3)").arg( name() ).arg( year().year() ).arg( concentrations().join(",") );
    }
    return asString;
}

