/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include <KLocale>

#include "error.h"

KFacebook::Error::Error() : m_errorCode( 0 )
{
}

KFacebook::Error::Error( int errorCode ) : m_errorCode( errorCode )
{
}

int KFacebook::Error::code() const
{
    return m_errorCode;
}

bool KFacebook::Error::isValid() const
{
    return m_errorCode != 0;
}

QString KFacebook::Error::toString() const
{
    QString errorString;
    switch ( m_errorCode ) {
        case -1:
            errorString = i18n("The XML response from the server could not be parsed");
            break;
        case 0:
            errorString = i18n("No error.  You can test for this using Error::isValid()");
            break;
        case 1:
            errorString = i18n("An unknown error occurred. Please resubmit the request.");
            break;
        case 2:
            errorString = i18n("The service is not available at this time.");
            break;
        case 4:
            errorString = i18n("The application has reached the maximum number of requests allowed. More requests are allowed once the time window has completed.");
            break;
        case 5:
            errorString = i18n("The request came from a remote address not allowed by this application.");
            break;
        case 100:
            errorString = i18n("One of the parameters specified was missing or invalid.");
            break;
        case 101:
            errorString = i18n("The api key submitted is not associated with any known application.");
            break;
        case 102:
            errorString = i18n("The session key was improperly submitted or has reached its timeout. Direct the user to log in again to obtain another key.");
            break;
        case 103:
            errorString = i18n("The submitted call_id was not greater than the previous call_id for this session.");
            break;
        case 104:
            errorString = i18n("Incorrect signature.");
            break;
        case 110:
            errorString = i18n("Invalid user id.");
            break;
        case 121:
            errorString = i18n("Invalid photo id.");
            break;
        case 240:
            errorString = i18n("The uid cannot be specified from a desktop application.");
            break;
        case 322:
            errorString = i18n("Invalid photo tag subject.");
            break;
        case 323:
            errorString = i18n("Cannot tag photo already visible on Facebook.");
            break;
        case 326:
            errorString = i18n("Too many photo tags pending.");
            break;
        case 330:
            errorString = i18n("The markup was invalid");
            break;
        case 601:
            errorString = i18n("Error while parsing FQL statement.");
            break;
        case 602:
            errorString = i18n("The field you requested does not exist.");
            break;
        case 603:
            errorString = i18n("The table you requested does not exist.");
            break;
        case 604:
            errorString = i18n("Your statement is not indexable.");
            break;
        case 605:
            errorString = i18n("The function you called down not exist.");
            break;
        case 606:
            errorString = i18n("Wrong number of arguments passed into the function.");
            break;
        default:
            errorString = i18n("ERROR Error: an unrecognized error was received from Facebook.");
    }
    return errorString;
}
