/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include <KDebug>

#include "event.h"

namespace KFacebook
{
class Event::Private
{
public:
    Private() : isNull( true ) {}
    Private( uint theEid, const QString & theName, const QString & theTagline, uint theNid, const KUrl & theSmallPicture, const KUrl & theMediumPicture, const KUrl & theLargePicture, const QString & theHost, const QString & theDescription, const QString & theType, const QString & theSubType, const QDateTime & theStartTime, const QDateTime & theEndTime, uint theCreator, const QDateTime & theUpdateTime, const QString & theLocation, const Venue & theVenue )
        : isNull( false ), eid( theEid ), name( theName ), tagline( theTagline ), nid( theNid),
        smallPicture( theSmallPicture ), mediumPicture( theMediumPicture ), largePicture( theLargePicture ), host( theHost ), description( theDescription ), type( theType ), subType( theSubType ), startTime( theStartTime ), endTime( theEndTime ), creator( theCreator ), updateTime( theUpdateTime ), location( theLocation ), venue( theVenue )
    {
    }

    ~Private() { }

    bool isNull;
    uint eid;
    QString name;
    QString tagline;
    uint nid;
    KUrl smallPicture;
    KUrl mediumPicture;
    KUrl largePicture;
    QString host;
    QString description;
    QString type;
    QString subType;
    QDateTime startTime;
    QDateTime endTime;
    uint creator;
    QDateTime updateTime;
    QString location;
    Venue venue;
};

} // namespace KFacebook

KFacebook::Event::Event() : d( new KFacebook::Event::Private )
{

}

KFacebook::Event::Event( uint eid, const QString & name, const QString & tagline, uint nid, const KUrl & smallPicture, const KUrl & mediumPicture, const KUrl & largePicture, const QString & host, const QString & description, const QString & type, const QString & subType, const QDateTime& startTime, const QDateTime & endTime, uint creator, const QDateTime & updateTime, const QString & location, const Venue & venue )
    : d( new KFacebook::Event::Private( eid, name, tagline, nid, smallPicture, mediumPicture, largePicture, host, description, type, subType, startTime, endTime, creator, updateTime, location, venue ) )
{

}

KFacebook::Event::Event( const KFacebook::Event & rhs ) : d( new KFacebook::Event::Private )
{
    operator=(rhs);
}

KFacebook::Event::~Event()
{
    delete d;
}

const KFacebook::Event& KFacebook::Event::operator=( const KFacebook::Event & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::Event::isNull() const
{
    return d->isNull;
}

uint KFacebook::Event::eid() const
{
    return d->eid;
}

QString KFacebook::Event::name() const
{
    return d->name;
}

QString KFacebook::Event::tagline() const
{
    return d->tagline;
}

uint KFacebook::Event::nid() const
{
    return d->nid;
}

KUrl KFacebook::Event::smallPicture() const
{
    return d->smallPicture;
}

KUrl KFacebook::Event::mediumPicture() const
{
    return d->mediumPicture;
}

KUrl KFacebook::Event::largePicture() const
{
    return d->largePicture;
}

QString KFacebook::Event::host() const
{
    return d->host;
}

QString KFacebook::Event::description() const
{
    return d->description;
}

QString KFacebook::Event::type() const
{
    return d->type;
}

QString KFacebook::Event::subType() const
{
    return d->subType;
}

QDateTime KFacebook::Event::startTime() const
{
    return d->startTime;
}

QDateTime KFacebook::Event::endTime() const
{
    return d->endTime;
}

uint KFacebook::Event::creator() const
{
    return d->creator;
}

QDateTime KFacebook::Event::updateTime() const
{
    return d->updateTime;
}

QString KFacebook::Event::location() const
{
    return d->location;
}

KFacebook::Venue KFacebook::Event::venue() const
{
    return d->venue;
}

void KFacebook::Event::dump() const
{
    kDebug() << "Event: " << d->eid << endl;
    kDebug() << " Name: " << d->name << endl;
    kDebug() << " Tagline: " << d->tagline << endl;
    kDebug() << " Nid: " << d->nid << endl;
    kDebug() << " Small picture:" << d->smallPicture.url() << endl;
    kDebug() << " Medium picture:" << d->mediumPicture.url() << endl;
    kDebug() << " Large picture:" << d->largePicture.url() << endl;
    kDebug() << " Host: " << d->host << endl;
    kDebug() << " Description: " << d->description << endl;
    kDebug() << " Type: " << d->type << endl;
    kDebug() << " Subtype: " << d->subType << endl;
    kDebug() << " Starts: " << d->startTime << endl;
    kDebug() << " Ends: " << d->endTime << endl;
    kDebug() << " Creator: " << d->creator << endl;
    kDebug() << " Updated: " << d->updateTime << endl;
    kDebug() << " Location: "<< d->location << endl;
    d->venue.dump();
}



