/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef KFACEBOOK_EVENT_H
#define KFACEBOOK_EVENT_H

#include <QDateTime>
#include <QString>
#include <KUrl>

#include <kfacebook/kfacebook_export.h>
#include <kfacebook/venue.h>

namespace KFacebook
{

class KFACEBOOK_EXPORT Event
{
public:
    Event();
    Event( uint eid, const QString & name, const QString & tagline, uint nid, const KUrl & smallPicture, const KUrl & mediumPicture, const KUrl & largePicture, const QString & host, const QString & description, const QString & type, const QString & subType, const QDateTime & startTime, const QDateTime & endTime, uint creator, const QDateTime & updateTime, const QString & location, const Venue & venue );
    Event( const Event & );
    const Event & operator=( const Event & );
    ~Event();
    bool isNull() const;
    uint eid() const;
    QString name() const;
    QString tagline() const;
    uint nid() const;
    KUrl smallPicture() const;
    KUrl mediumPicture() const;
    KUrl largePicture() const;
    QString host() const;
    QString description() const;
    QString type() const;
    QString subType() const;
    QDateTime startTime() const;
    QDateTime endTime() const;
    uint creator() const;
    QDateTime updateTime() const;
    QString location() const;
    Venue venue() const;

    void dump() const;
private:
    class Private;
    Private * const d;
};

} // namespace KFacebook

#endif // KFACEBOOK_EVENT_H
