/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include <KDebug>

#include "group.h"

namespace KFacebook
{
class Group::Private
{
public:
    Private() : isNull( true ) {}
    Private( uint theGid, const QString & theName, const QString & theDescription, uint theNid, const QString & theType, const QString & theSubType, const QString & theRecentNews, const KUrl & theSmallPicture, const KUrl & theMediumPicture, const KUrl & theLargePicture, uint theCreator, const QDateTime & theUpdateTime, const QString & theOffice, const QString & theWebsite , const Venue & theVenue ) :
        isNull( false ), gid( theGid ), name( theName ), description( theDescription ), nid( theNid),
        type( theType ), subType( theSubType ), recentNews( theRecentNews ), smallPicture( theSmallPicture ), mediumPicture( theMediumPicture ), largePicture( theLargePicture ), creator( theCreator ), updateTime( theUpdateTime ), office( theOffice ), website( theWebsite ), venue( theVenue )
    {
    }

    ~Private() { }

    bool isNull;
    uint gid;
    QString name;
    QString description;
    uint nid;
    QString type;
    QString subType;
    QString recentNews;
    KUrl smallPicture;
    KUrl mediumPicture;
    KUrl largePicture;
    uint creator;
    QDateTime updateTime;
    QString office;
    QString website;
    Venue venue;
};

} // namespace KFacebook

KFacebook::Group::Group() : d( new KFacebook::Group::Private )
{

}

KFacebook::Group::Group( uint gid, const QString & name, const QString & description, uint nid, const QString & type, const QString & subType, const QString & recentNews, const KUrl & smallPicture, const KUrl & mediumPicture, const KUrl & largePicture, uint creator, const QDateTime & updateTime, const QString & office, const QString & website, const Venue & venue )
    : d( new KFacebook::Group::Private( gid, name, description, nid, type, subType, recentNews, smallPicture, mediumPicture, largePicture, creator, updateTime, office, website, venue ) )
{

}

KFacebook::Group::Group( const KFacebook::Group & rhs ) : d( new KFacebook::Group::Private )
{
    operator=(rhs);
}

KFacebook::Group::~Group()
{
    delete d;
}

const KFacebook::Group& KFacebook::Group::operator=( const KFacebook::Group & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::Group::isNull() const
{
    return d->isNull;
}

uint KFacebook::Group::gid() const
{
    return d->gid;
}

QString KFacebook::Group::name() const
{
    return d->name;
}
uint KFacebook::Group::nid() const
{
    return d->nid;
}

QString KFacebook::Group::description() const
{
    return d->description;
}

QString KFacebook::Group::type() const
{
    return d->type;
}

QString KFacebook::Group::subType() const
{
    return d->subType;
}

QString KFacebook::Group::recentNews() const
{
    return d->recentNews;
}

KUrl KFacebook::Group::smallPicture() const
{
    return d->smallPicture;
}

KUrl KFacebook::Group::mediumPicture() const
{
    return d->mediumPicture;
}

KUrl KFacebook::Group::largePicture() const
{
    return d->largePicture;
}

uint KFacebook::Group::creator() const
{
    return d->creator;
}

QDateTime KFacebook::Group::updateTime() const
{
    return d->updateTime;
}

QString KFacebook::Group::office() const
{
    return d->office;
}

QString KFacebook::Group::website() const
{
    return d->website;
}

KFacebook::Venue KFacebook::Group::venue() const
{
    return d->venue;
}

void KFacebook::Group::dump() const
{
    kDebug() << "Group: " << d->gid << endl;
    kDebug() << " Name: " << d->name << endl;
    kDebug() << " Description: " << d->description << endl;
    kDebug() << " Nid: " << d->nid << endl;
    kDebug() << " Type: " << d->type << endl;
    kDebug() << " Subtype: " << d->subType << endl;
    kDebug() << " Recent news: " << d->recentNews << endl;
    kDebug() << " Small picture:" << d->smallPicture.url() << endl;
    kDebug() << " Medium picture:" << d->mediumPicture.url() << endl;
    kDebug() << " Large picture:" << d->largePicture.url() << endl;
    kDebug() << " Creator: " << d->creator << endl;
    kDebug() << " Updated: " << d->updateTime << endl;
    kDebug() << " Office: " << d->office << endl;
    kDebug() << " Website: " << d->website << endl;
    d->venue.dump();
}



