/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef KFACEBOOK_GROUP_H
#define KFACEBOOK_GROUP_H

#include <QDateTime>
#include <QString>
#include <KUrl>

#include <kfacebook/kfacebook_export.h>
#include <kfacebook/venue.h>

namespace KFacebook
{

class KFACEBOOK_EXPORT Group
{
public:
    Group();
    Group( uint gid, const QString & name, const QString & description, uint nid, const QString & type, const QString & subType, const QString & recentNews, const KUrl & smallPicture, const KUrl & mediumPicture, const KUrl & largePicture, uint creator, const QDateTime & updateTime, const QString & office, const QString & website , const Venue & venue );
    Group( const Group & );
    const Group & operator=( const Group & );
    ~Group();
    bool isNull() const;
    uint gid() const;
    QString name() const;
    uint nid() const;
    QString description() const;
    QString type() const;
    QString subType() const;
    QString recentNews() const;
    KUrl smallPicture() const;
    KUrl mediumPicture() const;
    KUrl largePicture() const;
    uint creator() const;
    QDateTime updateTime() const;
    QString office() const;
    QString website() const;
    Venue venue() const;

    void dump() const;
private:
    class Private;
    Private * const d;
};

} // namespace KFacebook

#endif // KFACEBOOK_GROUP_H
