/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include "highschoolinfo.h"

class HighschoolInfoPrivate
{
public:
    HighschoolInfoPrivate() : valid( false )
    { }
    HighschoolInfoPrivate( const QString & theName1, const QDate & theGradYear, uint theId1, const QString & theName2 , uint theId2 ) : valid( true ), name1( theName1 ), name2( theName2 ), gradYear( theGradYear ), id1( theId1 ), id2( theId2 )
    { }
    bool valid;
    QString name1;
    QString name2;
    QDate gradYear;
    uint id1;
    uint id2;
};

KFacebook::HighschoolInfo::HighschoolInfo() : d ( new HighschoolInfoPrivate )
{
}

KFacebook::HighschoolInfo::HighschoolInfo( const QString & name1, const QDate & gradYear, uint id1, const QString & name2 , uint id2 ) : d ( new HighschoolInfoPrivate( name1, gradYear, id1, name2, id2 ) )
{
}

KFacebook::HighschoolInfo::HighschoolInfo( const HighschoolInfo & rhs ) : d( new HighschoolInfoPrivate )
{
    operator=(rhs);
}

KFacebook::HighschoolInfo::~HighschoolInfo()
{
    delete d;
}

KFacebook::HighschoolInfo& KFacebook::HighschoolInfo::operator=( const HighschoolInfo& rhs )
{
    if ( &rhs != this )
        *d = *rhs.d;
    return *this;
}

bool KFacebook::HighschoolInfo::isNull() const
{
    return !d->valid;
}

QString KFacebook::HighschoolInfo::name1() const
{
    return d->name1;
}

QString KFacebook::HighschoolInfo::name2() const
{
    return d->name2;
}

QDate KFacebook::HighschoolInfo::gradYear() const
{
    return d->gradYear;
}

uint KFacebook::HighschoolInfo::id1() const
{
    return d->id1;
}

uint KFacebook::HighschoolInfo::id2() const
{
    return d->id2;
}

QString KFacebook::HighschoolInfo::toString() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null";
    } else {
        asString = QString("%1 %2 (%3), %4 (%5)").arg( name1() ).arg( gradYear().year() ).arg( id1() ).arg( name2() ).arg( id2() );
    }
    return asString;
}

