/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include "location.h"

class LocationPrivate
{
public:
    LocationPrivate() : valid( false )
    {
    }
    LocationPrivate( const QString & theCity, const QString & theCountry, const QString & theState, uint theZip )
        : valid( true ), city( theCity ), country( theCountry ), state( theState ), zip( theZip )
    { }
    bool valid;
    QString city;
    QString country;
    QString state;
    uint zip;
};

KFacebook::Location::Location() : d( new LocationPrivate )
{
}

KFacebook::Location::Location( const QString & city, const QString & country, const QString & state, uint zip ) : d ( new LocationPrivate( city, country, state, zip ) )
{
}

KFacebook::Location::Location( const Location & rhs ) : d( new LocationPrivate )
{
    operator=( rhs );
}

KFacebook::Location::~Location()
{
    delete d;
}

KFacebook::Location& KFacebook::Location::operator=( const Location & rhs )
{
    if ( &rhs != this ) {
        *d = *(rhs.d);
    }
    return *this;
}

bool KFacebook::Location::isNull() const
{
    return !d->valid;
}

QString KFacebook::Location::city() const
{
    return d->city;
}

QString KFacebook::Location::country() const
{
    return d->country;
}

QString KFacebook::Location::state() const
{
    return d->state;
}

uint KFacebook::Location::zip() const
{
    return d->zip;
}

QString KFacebook::Location::toString() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null";
    } else {
        asString = QString("%1 %2 %3, %4").arg( zip() ).arg( city() ).arg( state() ).arg( country() );
    }
    return asString;
}

