/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include <KDebug>

#include "userinfo.h"

class UserInfoPrivate
{
public:
    UserInfoPrivate() : valid( false )
    {}
    UserInfoPrivate( uint theUid,
              const QString &theAboutMe,
              const QString &theActivities,
              const QList<KFacebook::Affiliation> &theAffiliations,
              const QString &theBirthday,
              const QString &theBooks,
              const KFacebook::Location &theCurrentLocation,
              const QList<KFacebook::Education> &theEducationHistory,
              const QString &theFirstName,
              bool theHasApp,
              const KFacebook::HighschoolInfo &theHighschoolInfo,
              const KFacebook::Location &theHometown,
              const QString &theLastName,
              const QList<KFacebook::UserInfo::Seeking> &theLookingFor,
              const QList<KFacebook::UserInfo::Gender> &theInterestedIn,
              const QString &theMovies,
              const QString &theMusic,
              const QString &theName,
              int theNotesCount,
              const KUrl &theSmallPicture,
              const KUrl &theMediumPicture,
              const KUrl &theLargePicture,
              const KUrl &theSquarePicture,
              KFacebook::UserInfo::PoliticalView thePolitics,
              const QDateTime &theProfileTimestamp,
              const QString &theQuotes,
              KFacebook::UserInfo::RelationshipStatus theRelationshipStatus,
              const QString &theReligiousViews,
              KFacebook::UserInfo::Gender theSex,
              uint theSignificantOther,
              const QString &theStatus,
              const QDateTime &theStatusTimestamp,
              int theTimezoneOffset,
              const QString &theTv,
              int theWallCount,
              const QList<KFacebook::WorkInfo> &theWorkHistory )
                  : valid( true ), uid( theUid ), aboutMe( theAboutMe ), activities( theActivities ),
                  affiliations( theAffiliations ), birthday( theBirthday ), books( theBooks ),
                  currentLocation( theCurrentLocation ), educationHistory( theEducationHistory ),
                  firstName( theFirstName ), hasApp( theHasApp ), highschoolInfo( theHighschoolInfo ),
                  hometown( theHometown ),
                  lastName( theLastName ),
                  lookingFor( theLookingFor ), interestedIn( theInterestedIn ), movies( theMovies ),
                  music( theMusic ), name( theName ), notesCount( theNotesCount ),
                  smallPicture( theSmallPicture ), mediumPicture( theMediumPicture ),
                  largePicture( theLargePicture ), squarePicture( theSquarePicture ), politics( thePolitics ),
                  profileTimestamp( theProfileTimestamp ), quotes( theQuotes ),
                  relationshipStatus( theRelationshipStatus ), religiousViews( theReligiousViews ),
                  sex( theSex ), significantOther( theSignificantOther ), status( theStatus ),
                  statusTimestamp( theStatusTimestamp ), timezoneOffset( theTimezoneOffset ),
                  tv( theTv ), wallCount( theWallCount ), workHistory( theWorkHistory )
    { }
    bool valid;
    uint uid;
    QString aboutMe;
    QString activities;
    QList<KFacebook::Affiliation> affiliations;
    QString birthday;
    QString books;
    KFacebook::Location currentLocation;
    QList<KFacebook::Education> educationHistory;
    QString firstName;
    bool hasApp;
    KFacebook::HighschoolInfo highschoolInfo;
    KFacebook::Location hometown;
    QString interests;
    bool isAppUser;
    QString lastName;
    QList<KFacebook::UserInfo::Seeking> lookingFor;
    QList<KFacebook::UserInfo::Gender> interestedIn;
    QString movies;
    QString music;
    QString name;
    int notesCount;
    KUrl smallPicture;
    KUrl mediumPicture;
    KUrl largePicture;
    KUrl squarePicture;
    KFacebook::UserInfo::PoliticalView politics;
    QDateTime profileTimestamp;
    QString quotes;
    KFacebook::UserInfo::RelationshipStatus relationshipStatus;
    QString religiousViews;
    KFacebook::UserInfo::Gender sex;
    uint significantOther;
    QString status;
    QDateTime statusTimestamp;
    int timezoneOffset;
    QString tv;
    int wallCount;
    QList<KFacebook::WorkInfo> workHistory;
};

KFacebook::UserInfo::UserInfo() : d( new UserInfoPrivate )
{
}

KFacebook::UserInfo::UserInfo( uint uid,
              const QString &aboutMe,
              const QString &activities,
              const QList<Affiliation> &affiliations,
              const QString &birthday,
              const QString &books,
              const Location &currentLocation,
              const QList<Education> &educationHistory,
              const QString &firstName,
              bool hasApp,
              const HighschoolInfo &highschoolInfo,
              const Location &hometown,
              const QString &lastName,
              const QList<Seeking> &lookingFor,
              const QList<Gender> &interestedIn,
              const QString &movies,
              const QString &music,
              const QString &name,
              int notesCount,
              const KUrl &smallPicture,
              const KUrl &mediumPicture,
              const KUrl &largePicture,
              const KUrl &squarePicture,
              PoliticalView politics,
              const QDateTime &profileTimestamp,
              const QString &quotes,
              RelationshipStatus relationshipStatus,
              const QString &religiousViews,
              Gender sex,
              uint significantOther,
              const QString &status,
              const QDateTime &statusTimestamp,
              int timezoneOffset,
              const QString &tv,
              int wallCount,
              const QList<WorkInfo> &workHistory )
              : d ( new UserInfoPrivate( uid,
              aboutMe,
              activities,
              affiliations,
              birthday,
              books,
              currentLocation,
              educationHistory,
              firstName,
              hasApp,
              highschoolInfo,
              hometown,
              lastName,
              lookingFor,
              interestedIn,
              movies,
              music,
              name,
              notesCount,
              smallPicture,
              mediumPicture,
              largePicture,
              squarePicture,
              politics,
              profileTimestamp,
              quotes,
              relationshipStatus,
              religiousViews,
              sex,
              significantOther,
              status,
              statusTimestamp,
              timezoneOffset,
              tv,
              wallCount,
              workHistory ) )
{
}

KFacebook::UserInfo::UserInfo( const KFacebook::UserInfo & rhs) : d( new UserInfoPrivate )
{
    operator=( rhs );
}

KFacebook::UserInfo::~UserInfo()
{
    delete d;
}

KFacebook::UserInfo & KFacebook::UserInfo::operator=( const KFacebook::UserInfo & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::UserInfo::isNull() const
{
    return !d->valid;
}

uint KFacebook::UserInfo::uid() const
{
    return d->uid;
}

QString KFacebook::UserInfo::aboutMe() const
{
    return d->aboutMe;
}

QString KFacebook::UserInfo::activities() const
{
    return d->activities;
}

QList<KFacebook::Affiliation> KFacebook::UserInfo::affiliations() const
{
    return d->affiliations;
}

QString KFacebook::UserInfo::birthday() const
{
    return d->birthday;
}

QString KFacebook::UserInfo::books() const
{
    return d->books;
}

KFacebook::Location KFacebook::UserInfo::currentLocation() const
{
    return d->currentLocation;
}

QList<KFacebook::Education> KFacebook::UserInfo::educationHistory() const
{
    return d->educationHistory;
}

QString KFacebook::UserInfo::firstName() const
{
    return d->firstName;
}

bool KFacebook::UserInfo::hasApp() const
{
    return d->hasApp;
}

KFacebook::Location KFacebook::UserInfo::hometown() const
{
    return d->hometown;
}

KFacebook::HighschoolInfo KFacebook::UserInfo::highschoolInfo() const
{
    return d->highschoolInfo;
}

QString KFacebook::UserInfo::interests() const
{
    return d->interests;
}

bool KFacebook::UserInfo::isAppUser() const
{
    return d->isAppUser;
}

QString KFacebook::UserInfo::lastName() const
{
    return d->lastName;
}

QList<KFacebook::UserInfo::Seeking> KFacebook::UserInfo::lookingFor() const
{
    return d->lookingFor;
}

QList<KFacebook::UserInfo::Gender> KFacebook::UserInfo::interestedIn() const
{
    return d->interestedIn;
}

QString KFacebook::UserInfo::movies() const
{
    return d->movies;
}

QString KFacebook::UserInfo::music() const
{
    return d->music;
}

QString KFacebook::UserInfo::name() const
{
    return d->name;
}

int KFacebook::UserInfo::notesCount() const
{
    return d->notesCount;
}

KUrl KFacebook::UserInfo::smallPicture() const
{
    return d->smallPicture;
}

KUrl KFacebook::UserInfo::mediumPicture() const
{
    return d->mediumPicture;
}

KUrl KFacebook::UserInfo::largePicture() const
{
    return d->largePicture;
}

KUrl KFacebook::UserInfo::squarePicture() const
{
    return d->squarePicture;
}

KFacebook::UserInfo::PoliticalView KFacebook::UserInfo::politics() const
{
    return d->politics;
}

QDateTime KFacebook::UserInfo::profileTimestamp() const
{
    return d->profileTimestamp;
}

QString KFacebook::UserInfo::quotes() const
{
    return d->quotes;
}

KFacebook::UserInfo::RelationshipStatus KFacebook::UserInfo::relationshipStatus() const
{
    return d->relationshipStatus;
}

QString KFacebook::UserInfo::religiousViews() const
{
    return d->religiousViews;
}

KFacebook::UserInfo::Gender KFacebook::UserInfo::sex() const
{
    return d->sex;
}

uint KFacebook::UserInfo::significantOther() const
{
    return d->significantOther;
}

QString KFacebook::UserInfo::status() const
{
    return d->status;
}

QDateTime KFacebook::UserInfo::statusTimestamp() const
{
    return d->statusTimestamp;
}

int KFacebook::UserInfo::timezoneOffset() const
{
    return d->timezoneOffset;
}

QString KFacebook::UserInfo::tv() const
{
    return d->tv;
}

int KFacebook::UserInfo::wallCount() const
{
    return d->wallCount;
}

QList<KFacebook::WorkInfo> KFacebook::UserInfo::workHistory() const
{
    return d->workHistory;
}

void KFacebook::UserInfo::dump() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null";
    } else {
        kDebug() << "User Info for: " << d->uid << endl;
        kDebug() << "Name: " << d->name << "(" << d->firstName << "," << d->lastName << ")" << endl;
        kDebug() << "Status: " << d->status << endl;
        kDebug() << "About Me: " << d->aboutMe << endl;
        kDebug() << "Birthday: " << d->birthday << endl;
        kDebug() << "Books: " << d->books << endl;
        kDebug() << "Movies: " << d->movies << endl;
        kDebug() << "Quotes: " << d->quotes << endl;
        kDebug() << "TV: " << d->tv << endl;
        //kDebug() << "Interests: " << d->interests << endl;
        kDebug() << "Hometown: " << d->hometown.toString() << endl;
        kDebug() << "Current Location: " << d->currentLocation.toString() << endl;
        kDebug() << "Picture URLS:" << endl;
        kDebug() << "  small :" << d->smallPicture.url() << endl;
        kDebug() << "  medium:" << d->mediumPicture.url() << endl;
        kDebug() << "  large :" << d->largePicture.url() << endl;
        kDebug() << "  square:" << d->squarePicture.url() << endl;
        kDebug() << "Significant other uid:" << d->significantOther << endl;
        kDebug() << "Notes count: " << d->notesCount << ", Wall count: " << d->wallCount << endl;
        kDebug() << "Profile timestamp: " << d->profileTimestamp << ", Status timestamp: " << d->statusTimestamp << endl;
        kDebug() << "Timezone offset:" << d->timezoneOffset << endl;
       //kDebug()
        
        kDebug() << "Affiliations:" << endl;
        foreach (KFacebook::Affiliation aff, d->affiliations ) {
            kDebug() << "  " << aff.toString() << endl;
        }
        kDebug() << "High school info: " << d->highschoolInfo.toString() << endl;
        kDebug() << "Education history:" << endl;
        foreach (KFacebook::Education edu, d->educationHistory ) {
            kDebug() << "  " << edu.toString() << endl;
        }
        kDebug() << "Work history:" << endl;
        foreach (KFacebook::WorkInfo wi, d->workHistory ) {
            kDebug() << "  " << wi.toString() << endl;
        }
    }
}


bool KFacebook::UserInfo::operator<(const UserInfo & rhs) const
{
    return d->statusTimestamp < rhs.statusTimestamp();
}
