/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/


#ifndef KFACEBOOK_USERINFO_H
#define KFACEBOOK_USERINFO_H

#include <QDateTime>
#include <QList>

#include <kurl.h>

#include <kfacebook/kfacebook_export.h>

#include "affiliation.h"
#include "education.h"
#include "highschoolinfo.h"
#include "workinfo.h"

class UserInfoPrivate;

namespace KFacebook
{

class KFACEBOOK_EXPORT UserInfo
{
public:
    enum Seeking { Friendship, Relationship, Dating, RandomPlay, Whatever, UnspecifiedUrges };
    enum Gender { Male, Female, UnspecifiedGender };
    enum PoliticalView { VeryLiberal, Liberal, Moderate, Conservative, VeryConservative, Apathetic, Liberation, Other, UnspecifiedPolitics };
    enum RelationshipStatus { Single, InRelationship, InOpenRelationship, Engaged, Married, Complicated, UnspecifiedRelationshipStatus };

    UserInfo();
    UserInfo( uint uid,
              const QString &aboutMe,
              const QString &activities,
              const QList<Affiliation> &affiliations,
              const QString &birthday,
              const QString &books,
              const Location &currentLocation,
              const QList<Education> &educationHistory,
              const QString &firstName,
              bool hasApp,
              const HighschoolInfo &highschoolinfo,
              const Location &hometown,
              const QString &lastName,
              const QList<Seeking> &seeking,
              const QList<Gender> &interestedIn,
              const QString &movies,
              const QString &music,
              const QString &name,
              int notesCount,
              const KUrl &smallPicture,
              const KUrl &mediumPicture,
              const KUrl &largePicture,
              const KUrl &squarePicture,
              PoliticalView politics,
              const QDateTime &profileTimestamp,
              const QString &quotes,
              RelationshipStatus relationshipStatus,
              const QString &religiousViews,
              Gender sex,
              uint significantOther,
              const QString &status,
              const QDateTime &statusTimestamp,
              int timezoneOffset,
              const QString &tv,
              int wallCount,
              const QList<WorkInfo> &workHistory );
    UserInfo( const UserInfo & );
    ~UserInfo();
    UserInfo & operator=(const UserInfo &);
    bool  operator<(const UserInfo &) const;
    bool isNull() const;
    uint uid() const;
    QString aboutMe() const;
    QString activities() const;
    QList<Affiliation> affiliations() const;
    QString birthday() const;
    QString books() const;
    Location currentLocation() const;
    QList<Education> educationHistory() const;
    QString firstName() const;
    bool hasApp() const;
    Location hometown() const;
    HighschoolInfo highschoolInfo() const;
    QString interests() const;
    bool isAppUser() const;
    QString lastName() const;
    QList<Seeking> lookingFor() const;
    QList<Gender> interestedIn() const;
    QString movies() const;
    QString music() const;
    QString name() const;
    int notesCount() const;
    KUrl smallPicture() const;
    KUrl mediumPicture() const;
    KUrl largePicture() const;
    KUrl squarePicture() const;
    PoliticalView politics() const;
    QDateTime profileTimestamp() const;
    QString quotes() const;
    RelationshipStatus relationshipStatus() const;
    QString religiousViews() const;
    Gender sex() const;
    uint significantOther() const;
    QString status() const;
    QDateTime statusTimestamp() const;
    int timezoneOffset() const;
    QString tv() const;
    int wallCount() const;
    QList<WorkInfo> workHistory() const;

    void dump() const;
private:
    UserInfoPrivate * d;
};

} // namespace KFacebook
#endif // KFACEBOOK_USERINFO_H
