/*  This file is part of the KDE project
    Copyright (C) 2007,2008 Will Stephenson <wstephenson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library.  If not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include "workinfo.h"

class WorkInfoPrivate
{
public:
    WorkInfoPrivate() : valid( false )
    { }
    WorkInfoPrivate( const KFacebook::Location & theLocation, const QString & theCompanyName, const QDate & theStart, const QDate & theEnd, const QString & theDescription, const QString & thePosition )
        : valid( true ), location( theLocation ), companyName( theCompanyName ), start( theStart ), end( theEnd ), description( theDescription ), position( thePosition )
    {
    }

    bool valid;
    KFacebook::Location location;
    QString companyName;
    QDate start;
    QDate end;
    QString description;
    QString position;
};

KFacebook::WorkInfo::WorkInfo() : d( new WorkInfoPrivate )
{
}

KFacebook::WorkInfo::WorkInfo( const Location & location, const QString & companyName, const QDate & start, const QDate & end, const QString & description, const QString & position ) : d( new WorkInfoPrivate( location, companyName, start, end, description, position ) )
{
}

KFacebook::WorkInfo::WorkInfo( const WorkInfo & rhs ) : d( new WorkInfoPrivate )
{
    operator=( rhs );
}

KFacebook::WorkInfo::~WorkInfo()
{
    delete d;
}

KFacebook::WorkInfo& KFacebook::WorkInfo::operator=( const WorkInfo & rhs )
{
    if ( &rhs != this ) {
        *d = *rhs.d;
    }
    return *this;
}

bool KFacebook::WorkInfo::isNull() const
{
    return !d->valid;
}

KFacebook::Location KFacebook::WorkInfo::location() const
{
    return d->location;
}

QString KFacebook::WorkInfo::companyName() const
{
    return d->companyName;
}

QDate KFacebook::WorkInfo::start() const
{
    return d->start;
}

QDate KFacebook::WorkInfo::end() const
{
    return d->end;
}

QString KFacebook::WorkInfo::description() const
{
    return d->description;
}

QString KFacebook::WorkInfo::position() const
{
    return d->position;
}

QString KFacebook::WorkInfo::toString() const
{
    QString asString;
    if ( isNull() ) {
        asString = "(null";
    } else {
        asString = QString("%1 at %2").arg( position() ).arg( companyName() );
        if ( !start().isNull() ) {
            asString.append( QString(", from %1 %2").arg( start().month() ). arg( start().year() ) );
        }
        if ( !end().isNull() ) {
            asString.append( QString(", to %1 %2").arg( end().month() ). arg( end().year() ) );
        }
        if ( !location().isNull() ) {
            asString.append( QString(", in %1 ").arg( location().toString() ) );
        }
        if ( !description().isEmpty() ) {
            asString.append( QString(", description: '%1'" ).arg( description() ) );
        }
    }
    return asString;
}

