/* This file is part of the KDE project
   Copyright 2007,2008 Will Stephenson <wstephenson@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QPainter>
#include <KDebug>
#include <KDialog>
#include <KLocale>
#include <KIO/TransferJob>
#include <KIO/Job>

#include <plasma/svg.h>
#include <plasma/widgets/pushbutton.h>
#include <plasma/widgets/textedit.h>

#include "facebook.h"

Facebook::Facebook(QObject * parent, const QVariantList & args)
    : Plasma::Applet( parent, args),
      m_tutorialIcon("document"),
      m_size( 250, 250 ),
      m_dialog( 0 ),
      m_selectedFriend( 0 )
{
    setHasConfigurationInterface( true );
    m_tutorialTheme = new Plasma::Svg( this );
    m_tutorialTheme->setImagePath("widgets/background");

    m_engine = dataEngine("facebook");
    if ( m_engine )
    {
        connect(m_engine, SIGNAL(sourceAdded(const QString &)), this, SLOT(sourceAdded(const QString &)));
        connect(m_engine, SIGNAL(sourceRemoved(const QString &)), this, SLOT(sourceRemoved(const QString &)));
    }
    else
        kDebug()<<" We can not connect to facebook engine";

    m_friend = new Plasma::TextEdit( this );
    //m_friend->setStyled( false );
    m_friend->setEnabled( false );
    m_friend->setCursor( Qt::ArrowCursor );
    m_friend->setAcceptedMouseButtons( Qt::NoButton );

    //setDrawStandardBackground( true );


    m_layout = new QGraphicsLinearLayout(this);
    m_layout->setContentsMargins(0, 0, 0, 0);
    m_layout->setSpacing(0);
    m_layout->addItem(m_friend);

    // detect if the engine already has a session
    KConfig config( QString::fromLatin1( "libkfacebookrc" ) );
    KConfigGroup group = config.group("Session");
    m_sessionKey = group.readEntry( "SessionKey" );
    QVariant defaultExp = QDateTime::currentDateTime();
    QVariant expiry = group.readEntry( "SessionExpires", defaultExp );
    m_sessionExpires = expiry.toDateTime();
    m_sessionSecret = group.readEntry( "SessionSecret" );

    if ( !( m_sessionExpires < QDateTime::currentDateTime() || m_sessionKey.isNull() || m_sessionSecret.isEmpty() ) ) {
        m_engine->setProperty( "sessionkey", m_sessionKey );
        m_engine->setProperty( "sessionexpires", m_sessionExpires );
        m_engine->setProperty( "sessionsecret", m_sessionSecret );
    }
}

Facebook::~Facebook()
{
}

void Facebook::showConfigurationInterface()
{
    if ( m_dialog == 0 ) {
        m_dialog = new KDialog;
        m_ui.setupUi( m_dialog->mainWidget() );
        connect( m_dialog, SIGNAL(okClicked()), this, SLOT(configAccepted()) );
        m_ui.cmbFriend->addItems( m_engine->sources() );
    }
    m_dialog->show();
}

void Facebook::sourceAdded(const QString& source)
{
#if 0
    Plasma::LineEdit* text = new Plasma::LineEdit(this);
    text->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);
    text->setObjectName(source);
    kDebug() << "added " << text->objectName() << " with expandings " << text->expandingDirections() << endl;
    m_engine->connectSource(source, text);
    // this still doesn't do any laying out as of 20070729
    m_layout->addItem(text);
#endif
}

void Facebook::sourceRemoved(const QString& source)
{
#if 0
    foreach (QGraphicsItem * child, QGraphicsItem::children()) {
        Plasma::LineEdit * text = dynamic_cast<Plasma::LineEdit*>(child);
        if (!text) {
            continue;
        }

        if (text->objectName() == source) {
            delete text;
        }
        return;
    }
#endif
}

void Facebook::configAccepted()
{
    kDebug() << endl;
    m_engine->setProperty( "tokenAuthenticated", true );
    m_selectedFriend = m_ui.cmbFriend->currentText();
    m_engine->connectSource( m_ui.cmbFriend->currentText(), this );
    Plasma::DataEngine::Data data = m_engine->query( m_ui.cmbFriend->currentText() );
    downloadImage( m_selectedFriend, KUrl( data.value("picture").toString() ) );
    dataUpdated( m_ui.cmbFriend->currentText(), data );
}

void Facebook::dataUpdated(const QString& source, const Plasma::DataEngine::Data &data)
{
    kDebug() << endl;
    QString html = "<p>Blah</p><table cellspacing='0'>";
    html += i18n( "<tr><td width='1%'><font color='#fcfcfc'><b>%1</b></font></td>"
            "<td align='right' width='99%'><font color='#fcfcfc'>%2</font></td></tr>",
            data.value( "name" ).toString(), data.value( "statusupdatetime" ).toDateTime().toString() );
    html += QString( "<tr><td colspan='2'><font color='#fcfcfc'>%1<br></font></td></tr>" )
        .arg( data.value( "status" ).toString() );
    html += "</table><p>Blubb</p>";
    //In plasma TextEdit widget "setText" adds text as html
    m_friend->setText( html );
    update();

}

void Facebook::paintInterface( QPainter *p,
        const QStyleOptionGraphicsItem * option, const QRect &contents )
{
     if ( !m_pictureMap[m_selectedFriend].isNull() ) {
         p->drawPixmap( contents.x()+3, contents.y()+21, m_pictureMap[m_selectedFriend] );
     }
    /*
    m_tutorialTheme.resize(boundingRect().width(),
            boundingRect().height());
    m_tutorialTheme.paint(p,
            boundingRect().left(),
            boundingRect().top());

    // The we place the icon and text
    p->drawPixmap(20, 0,
            m_tutorialIcon.pixmap(boundingRect().width() - 40));
    p->save();
    p->setPen(Qt::white);
    p->drawText(boundingRect(),
            Qt::AlignBottom+Qt::AlignHCenter,
            "Hello Plasmoid!");
    p->restore();
    */
}

void Facebook::downloadImage( const QString &nick, const KUrl &url )
{
    kDebug() << endl;
    if( m_pictureDownloadMap.values().contains( nick ) )
        return;

    KIO::TransferJob *job = KIO::get( url );
    connect( job, SIGNAL(result(KJob *)), SLOT(imageDownloadResult(KJob *)) );
    connect( job, SIGNAL(data(KIO::Job *,const QByteArray &)), SLOT(imageData(KIO::Job *,const QByteArray &)) );

    m_pictureDownloadMap[job] = nick;
}

void Facebook::imageData( KIO::Job *job, const QByteArray &data )
{
    Q_UNUSED( job );
    m_bufferMap[job].append( data );
}

void Facebook::imageDownloadResult(KJob *j)
{
    kDebug() << endl;
    KIO::TransferJob *job = static_cast<KIO::TransferJob *>(j);

    if( !job->isErrorPage() ) {
        QImage img;
        img.loadFromData( m_bufferMap[job] );
        QPixmap pm = QPixmap::fromImage( img );
        QString nick = m_pictureDownloadMap[job];

        m_pictureMap[ nick ] = pm;
        //emit pictureDownloaded( nick );
        imageDownloaded( nick ); // TODO: That should later connect to the tweet widgets
    } else {
        kDebug() << "Error while downloading Image" << job->error() << endl;
    }
}

void Facebook::imageDownloaded( const QString &nick )
{
    kDebug() << endl;
    //geometryChanged();
}

#include "facebook.moc"


