/* This file is part of the KDE project
   Copyright 2007,2008 Will Stephenson <wstephenson@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_FACEBOOK_APPLET_H
#define PLASMA_FACEBOOK_APPLET_H

#include <plasma/applet.h>
#include <plasma/dataengine.h>
#include <QGraphicsLinearLayout>

#include "ui_login.h"
#include "ui_facebookconfig.h"

class KDialog;
class KJob;

namespace KIO
{
    class Job;
} // namespace KIO

namespace Plasma
{
    class DataEngine;
} // namespace Plasma

class Facebook : public Plasma::Applet
{
Q_OBJECT
public:
    Facebook( QObject * parent, const QVariantList & args );
    ~Facebook();

    void paintInterface( QPainter *p,
        const QStyleOptionGraphicsItem * option, const QRect & contents );
public slots:
    void showConfigurationInterface();
private slots:
    void imageData( KIO::Job *job, const QByteArray &data );
    void imageDownloadResult( KJob *job );
    void imageDownloaded( const QString &nick );

    void sourceAdded(const QString& source);
    void sourceRemoved(const QString& source);
    void dataUpdated(const QString& source, const Plasma::DataEngine::Data &data);
    void configAccepted();
protected:
    void downloadImage( const QString &nick, const KUrl &url );
private:
    Plasma::DataEngine* m_engine;
    QWidget * m_loginWidget;
    Ui_Login ui;
    uint m_frequency;
    QString m_sessionKey;
    QDateTime m_sessionExpires;
    QString m_sessionSecret;
    // temporary
    Plasma::Svg *m_tutorialTheme;
    KIcon m_tutorialIcon;
    QSizeF m_size;
    KDialog * m_dialog;
    Ui_ConfigUi m_ui;
    QString m_selectedFriend;
    Plasma::TextEdit * m_friend;
    QGraphicsLinearLayout *m_layout;
    QMap< QString, QPixmap > m_pictureMap;
    QMap< KJob *, QString > m_pictureDownloadMap;
    QMap< KJob *, QByteArray > m_bufferMap;
};

K_EXPORT_PLASMA_APPLET(facebook, Facebook)

#endif
