/* This file is part of the KDE project
   Copyright 2007,2008 Will Stephenson <wstephenson@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QTimer>
#include <KJob>
#include <kfacebook/fbjobs.h>
#include <kfacebook/method.h>
#include <kfacebook/session.h>
#include <kfacebook/userinfo.h>
#include <kfacebook/version.h>

#include "facebook.h"
#define UPDATE_CHECK_PERIOD_MS 5 * 60 * 1000

FacebookEngine::FacebookEngine( QObject * parent, const QVariantList & ) : Plasma::DataEngine( parent ) , m_session( 0 ), m_timer( new QTimer( this ) )
{
    kDebug() << endl;
    connect( m_timer, SIGNAL( timeout() ), SLOT( update() ) );
    m_session = new KFacebook::Session( this, KFACEBOOK_API_KEY, KFACEBOOK_SECRET_KEY );
    if ( m_session->state() == KFacebook::Session::Authenticated ) {
        requestFriendsList();
    } else {
        connect( m_session, SIGNAL( ready() ), this, SLOT( requestFriendsList() ) );
    }
}

FacebookEngine::~FacebookEngine()
{
}

void FacebookEngine::init()
{
    kDebug() << endl;
}

bool FacebookEngine::sourceRequested( const QString & name )
{
#if 0
    }
    m_friends << name.toUInt();
    update();

    if ( !m_timer->isActive() ) {
        m_timer->start( 30000 );
    }
#endif
    return false;
}

void FacebookEngine::setTokenAuthenticated( bool authed )
{
    if ( authed ) {
        m_session->browserLoggedIn();
    }
}

void FacebookEngine::requestFriendsList()
{
    kDebug() << endl;
    if ( m_friends.isEmpty() ) {
        KFacebook::Job * job = m_session->friendsGetJob();
        connect( job, SIGNAL( result( KJob * ) ), SLOT( gotFriendsList( KJob * ) ) );
    }
}

void FacebookEngine::gotFriendsList( KJob * job )
{
    KFacebook::FriendsGetJob * gfJob  = static_cast< KFacebook::FriendsGetJob * >( job );
    m_friends = gfJob->friends().mid(0, 5);
    update();
    if ( !m_timer->isActive() ) {
        m_timer->start( UPDATE_CHECK_PERIOD_MS );
    }
}

void FacebookEngine::update()
{
    kDebug() << endl;
    QStringList wantedFields;
    wantedFields << KFacebook::Method::FIELD_NAME << KFacebook::Method::FIELD_PICTURE_SMALL << KFacebook::Method::FIELD_STATUS << KFacebook::Method::FIELD_PROFILE_UPDATE_TIME;
    // get the data for the requested users and update the Data
    KFacebook::Job * job = m_session->usersGetInfoJob( m_friends, wantedFields );
    connect( job, SIGNAL( result( KJob * ) ), SLOT( processUserInfo( KJob * ) ) );
}

void FacebookEngine::processUserInfo( KJob * job )
{
    KFacebook::UsersGetInfoJob * uiJob = static_cast< KFacebook::UsersGetInfoJob * >( job );
    QList<KFacebook::UserInfo> userInfoList = uiJob->userInfo();
    qSort( userInfoList );
    for ( int i = 0; i < userInfoList.count() /*&& i < 10*/; ++i ) {
        KFacebook::UserInfo info = userInfoList[i];
        setData( QString::number( info.uid() ), "name", info.name() );
        setData( QString::number( info.uid() ), "picture", info.smallPicture().url() );
        setData( QString::number( info.uid() ), "status", info.status() );
        setData( QString::number( info.uid() ), "statusupdatetime", info.statusTimestamp() );
        setData( QString::number( info.uid() ), "profileupdatetime", info.profileTimestamp() );
    }
    scheduleSourcesUpdated();
}

#include "facebook.moc"
